@@ -342,22 +342,49 @@ void TestMaxima::testHelpRequest()
     QVERIFY(e->results().size() == 2); //two results, the warning and the actual result of the calculation
 }
 
+void TestMaxima::testTextQuotes()
+{
+    // check simple sting
+    auto* e1 = evalExp(QLatin1String("t1: \"test string\""));
+    QVERIFY(e1 != nullptr);
+
+    if(session()->status()==Cantor::Session::Running)
+        waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
+
+    QVERIFY(e1->result() != nullptr);
+    QCOMPARE(e1->result()->type(), (int)Cantor::TextResult::Type );
+    QCOMPARE(e1->result()->data().toString(), QLatin1String("test string"));
+
+    // check string with quotes inside
+    auto* e2 = evalExp(QLatin1String("t2: \"this is a \\\"quoted string\\\"\""));
+    QVERIFY(e2 != nullptr);
+
+    if(session()->status()==Cantor::Session::Running)
+        waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
+
+    QVERIFY(e2->result() != nullptr);
+    QCOMPARE(e2->result()->type(), (int)Cantor::TextResult::Type );
+    QCOMPARE(e2->result()->data().toString(), QLatin1String("this is a \"quoted string\""));
+}
+
 void TestMaxima::testVariableModel()
 {
     QAbstractItemModel* model = session()->variableModel();
     QVERIFY(model != nullptr);
 
-    auto* e1=evalExp(QLatin1String("a: 15"));
-    auto* e2=evalExp(QLatin1String("a: 15; b: \"Hello, world!\""));
-    auto* e3=evalExp(QLatin1String("l: [1,2,3]"));
-    QVERIFY(e1!=nullptr);
-    QVERIFY(e2!=nullptr);
-    QVERIFY(e3!=nullptr);
+    auto* e1 = evalExp(QLatin1String("a: 15"));
+    auto* e2 = evalExp(QLatin1String("a: 15; b: \"Hello, world!\""));
+    auto* e3 = evalExp(QLatin1String("l: [1,2,3]"));
+    auto* e4 = evalExp(QLatin1String("t: \"this is a \\\"quoted string\\\"\""));
+    QVERIFY(e1 != nullptr);
+    QVERIFY(e2 != nullptr);
+    QVERIFY(e3 != nullptr);
+    QVERIFY(e4 != nullptr);
 
     if(session()->status()==Cantor::Session::Running)
         waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
 
-    QCOMPARE(3, model->rowCount());
+    QCOMPARE(4, model->rowCount());
 
     QVariant name = model->index(0,0).data();
     QCOMPARE(name.toString(),QLatin1String("a"));
@@ -369,13 +396,19 @@ void TestMaxima::testVariableModel()
     QCOMPARE(name1.toString(),QLatin1String("b"));
 
     QVariant value1 = model->index(1,1).data();
-    QCOMPARE(value1.toString(),QLatin1String("\"Hello, world!\""));
+    QCOMPARE(value1.toString(),QLatin1String("Hello, world!"));
 
     QVariant name2 = model->index(2,0).data();
     QCOMPARE(name2.toString(),QLatin1String("l"));
 
     QVariant value2 = model->index(2,1).data();
     QCOMPARE(value2.toString(),QLatin1String("[1,2,3]"));
+
+    QVariant name3 = model->index(3,0).data();
+    QCOMPARE(name3.toString(),QLatin1String("t"));
+
+    QVariant value3 = model->index(3,1).data();
+    QCOMPARE(value3.toString(),QLatin1String("this is a \"quoted string\""));
 }
 
 void TestMaxima::testLispMode01()
